﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.VisualBasic.FileIO;
using System.Diagnostics;
using System.IO;

namespace テキスト差込ツール
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // CSVファイル選択
        private void button1_Click(object sender, EventArgs e)
        {
            // 以下の３行は オプション（なくてもＯＫ）
            openFileDialog1.Title            = "CSVファイルの選択" ;  // タイトルバーの文字列
            // openFileDialog1.InitialDirectory = "???" ;  // 最初に表示されるディレクトリ
            openFileDialog1.Filter = "CSVファイル (*.CSV)|*.CSV";  //「ファイルの種類」を指定

            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                textBox1.Text = openFileDialog1.FileName;
            }
        }

        // テンプレート選択
        private void button2_Click(object sender, EventArgs e)
        {
            // 以下の３行は オプション（なくてもＯＫ）
            openFileDialog1.Title = "テンプレートの選択";  // タイトルバーの文字列
            // openFileDialog1.InitialDirectory = "???" ;  // 最初に表示されるディレクトリ
            openFileDialog1.Filter = "HTMLファイル (*.HTML;*.HTM)|*.HTML;*.HTM|テキストファイル (*.TXT)|*.TXT|すべてのファイル (*.*)|*.*";  //「ファイルの種類」を指定

            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                textBox2.Text = openFileDialog1.FileName;
            }

        }

        // 実行
        private void button3_Click(object sender, EventArgs e)
        {
            if (!File.Exists(textBox1.Text))
            {
                MessageBox.Show("CSVファイルがありません。","読み込みエラー",MessageBoxButtons.OK,MessageBoxIcon.Warning);
                return;
            }
            if (!File.Exists(textBox2.Text))
            {
                MessageBox.Show("テンプレートがありません。", "読み込みエラー", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            string baseDir = System.AppDomain.CurrentDomain.BaseDirectory + Path.GetFileNameWithoutExtension(textBox1.Text);
            Directory.CreateDirectory(baseDir);

            // 行数取得
            int linecnt = lineCount(textBox1.Text);

            // テンプレートの読み込み
            StreamReader reader = new StreamReader(textBox2.Text, Encoding.GetEncoding("Shift_JIS"));
            string template = reader.ReadToEnd();
            reader.Close();

            // TextFieldParserクラスのコンストラクタ呼び出し
            TextFieldParser parser = new TextFieldParser(textBox1.Text,
                System.Text.Encoding.GetEncoding("Shift_JIS"));

            // フィールドがコンマで区切られている場合の設定
            parser.TextFieldType = FieldType.Delimited;
            parser.SetDelimiters(","); // 区切り文字はコンマ

            // 差込記号の取得
            if (parser.EndOfData)
            {
                MessageBox.Show("CSVファイルの読み込みに失敗しました。", "読み込みエラー", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }
            string[] kigou = parser.ReadFields(); // 1行読み込み
            if (kigou.Length < 2) 
            {
                MessageBox.Show("差込記号の読み込みに失敗しました。", "読み込みエラー", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            // CSVファイル全体を読み込みながら処理するループ
            Form2 form2 = new Form2();
            form2.setMax(linecnt);
            form2.Show(this);
            int cnt = 0;
            form2.setValue(++cnt);
            while (!parser.EndOfData)
            {
                string[] row = parser.ReadFields(); // 1行読み込み
                row[0] = row[0].Trim();
                if (row[0].Length > 0)
                {
                    string buf = template; // 出力用バッファ

                    for (int idx = 1; idx < row.Length; idx++)
                    {
                        buf = buf.Replace(kigou[idx], row[idx]); // 置換
                    }

                    StreamWriter writer = new StreamWriter(baseDir + "\\" + row[0], false,  // 上書き （ true = 追加 ）
                                                           Encoding.GetEncoding("Shift_JIS"));
                    writer.Write(buf);
                    writer.Close();
                }

                form2.setValue(++cnt);
                Application.DoEvents();
                //System.Threading.Thread.Sleep(10000); 
            }
            form2.Dispose();
            Process.Start("explorer.exe", "/n," + baseDir);
        }

        // 行数取得
        private int lineCount(string fname)
        {
            int count = 0;
            StreamReader reader = new StreamReader(fname,Encoding.GetEncoding("Shift_JIS"));
            while (reader.ReadLine() != null)
            {
                count++;
            }
            reader.Close();

            return count;
        }

        // 終了
        private void button4_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }
   }
}